.main[data-v-7f6e4de7]{display:flex;flex-flow:row;height:100%;width:100%;font-size:120%}.left[data-v-7f6e4de7],.right[data-v-7f6e4de7]{box-sizing:border-box;flex:1 1 auto;overflow:scroll}.resizer[data-v-7f6e4de7]{width:5px;padding:0;cursor:ew-resize;flex:0 0 auto}.resizer[data-v-7f6e4de7]:hover{background:#d3d3d3}.fileList[data-v-675b1bdb]{margin-left:5px;padding-left:10px}.dir[data-v-675b1bdb]:hover,.file[data-v-675b1bdb]:hover{background:#ddd}.supported-false[data-v-675b1bdb]{color:#888}.fileBrowser[data-v-62ea5f48]{background:#eee;overflow-x:hidden;cursor:default}.annotation-button[data-v-1197ac49],.annotation-button[data-v-37717980]{border-radius:20px;background:#60911b;padding:0 5px;color:#fff;font-weight:700;font-family:Avenir,Helvetica,Arial,sans-serif;font-size:smaller;cursor:pointer}.code[data-v-6538b917]{overflow:scroll;height:100%}.error{white-space:pre-wrap;border-radius:20px;background:#e84412;padding:7px;color:#fff;font-weight:700;font-size:smaller;margin:5px 0}.verification-condition{padding:5px 0;display:block}.vc-formula{border-radius:15px;background:#1b6a91;padding:0 5px;color:#fff;font-weight:700;font-family:Avenir,Helvetica,Arial,sans-serif;font-size:smaller}.outdated .vc-formula{background:#646464}.vc-button{border-radius:20px;background:#60911b;padding:0 5px;color:#fff;font-weight:700;font-family:Avenir,Helvetica,Arial,sans-serif;font-size:smaller;cursor:pointer}.vc-icon{vertical-align:middle;margin:0 20px}button{font-size:100%;margin-right:2px}.errors ul[data-v-39f2bcfc]{margin:0;padding:0}.error[data-v-39f2bcfc]{white-space:pre-wrap;border-radius:20px;background:#e84412;padding:7px;color:#fff;font-weight:700;font-size:smaller;margin:5px 0}.msg[data-v-39f2bcfc]{padding:7px}.close-button[data-v-39f2bcfc]{float:right;fill:#fff;opacity:.9;display:block;padding:7px}.close-button[data-v-39f2bcfc]:hover{opacity:1;cursor:pointer}.page{height:100%}.toolbar[data-v-258d1f32]{background:#434343;color:#fff}.toolbar .group[data-v-258d1f32]{display:inline-block;margin-right:20px}.toolbar button[data-v-258d1f32]{font-size:100%;margin:2px;padding:2px 10px;border-radius:20px;border:2px solid #ddd;color:#ddd;background:#434343;font-family:sans-serif;font-weight:700;cursor:pointer}.toolbar button[data-v-258d1f32]:hover{color:#fff;border:2px solid #fff}#app,body,html{height:100%;margin:0;font-family:Avenir,Helvetica,Arial,sans-serif}#app{font-size:80%}#app,.pages{display:flex;flex-flow:column;height:100%;overflow:hidden}.tab{display:inline-block;background:#ccc;margin:0 1px;padding:10px;width:200px;text-align:center;cursor:default}.close{float:right;padding:8px 0}.tab.open{background:#fff}#main,.page{flex:1 1 auto;overflow:hidden}.tabs,.toolbar{flex:0 1 auto}